======================================
``psyclone.domain.lfric.arg_ordering``
======================================

.. automodule:: psyclone.domain.lfric.arg_ordering

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.arg_ordering


Classes
=======

- :py:class:`ArgOrdering`:
  Base class capturing the arguments, type and ordering of data in


.. autoclass:: ArgOrdering
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArgOrdering
      :parts: 1
